@@ -362,6 +362,55 @@ dmap_marshal_BOOLEAN__STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
+/* VOID:STRING,POINTER,POINTER,POINTER,BOOLEAN (./dmap-marshal.list:8) */
+extern void dmap_marshal_VOID__STRING_POINTER_POINTER_POINTER_BOOLEAN (GClosure     *closure,
+                                                                       GValue       *return_value,
+                                                                       guint         n_param_values,
+                                                                       const GValue *param_values,
+                                                                       gpointer      invocation_hint,
+                                                                       gpointer      marshal_data);
+void
+dmap_marshal_VOID__STRING_POINTER_POINTER_POINTER_BOOLEAN (GClosure     *closure,
+                                                           GValue       *return_value G_GNUC_UNUSED,
+                                                           guint         n_param_values,
+                                                           const GValue *param_values,
+                                                           gpointer      invocation_hint G_GNUC_UNUSED,
+                                                           gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__STRING_POINTER_POINTER_POINTER_BOOLEAN) (gpointer     data1,
+                                                                             gpointer     arg_1,
+                                                                             gpointer     arg_2,
+                                                                             gpointer     arg_3,
+                                                                             gpointer     arg_4,
+                                                                             gboolean     arg_5,
+                                                                             gpointer     data2);
+  register GMarshalFunc_VOID__STRING_POINTER_POINTER_POINTER_BOOLEAN callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 6);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__STRING_POINTER_POINTER_POINTER_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_string (param_values + 1),
+            g_marshal_value_peek_pointer (param_values + 2),
+            g_marshal_value_peek_pointer (param_values + 3),
+            g_marshal_value_peek_pointer (param_values + 4),
+            g_marshal_value_peek_boolean (param_values + 5),
+            data2);
+}
+
 G_END_DECLS
 
 #endif /* __dmap_marshal_MARSHAL_H__ */
