@@ -24,13 +24,16 @@
 #include <glib.h>
 
 G_BEGIN_DECLS
+	void dmap_hash_generate (short version_major,
+				 const guchar * url,
+				 guchar hash_select,
+				 guchar * out, gint request_id);
 
-void dmap_hash_generate (short version_major,
-                         const guchar *url,
-                         guchar hash_select,
-                         guchar *out,
-                         gint request_id);
+#ifdef HAVE_CHECK
+#include <check.h>
+
+Suite *dmap_test_daap_connection_suite (void);
+#endif
 
 G_END_DECLS
-
 #endif
