@@ -19,11 +19,12 @@
  */
 
 #include <string.h>
+#include <gst/gst.h>
 
-#include "g-gst-input-stream.h"
+#include "dmap-gst-input-stream.h"
 
 gboolean
-pads_compatible (GstPad *pad1, GstPad *pad2)
+pads_compatible (GstPad * pad1, GstPad * pad2)
 {
 	gboolean fnval;
 	GstCaps *res, *caps1, *caps2;
@@ -31,7 +32,7 @@ pads_compatible (GstPad *pad1, GstPad *pad2)
 	caps1 = gst_pad_get_caps (pad1);
 	caps2 = gst_pad_get_caps (pad2);
 	res = gst_caps_intersect (caps1, caps2);
-	fnval = res && ! gst_caps_is_empty (res);
+	fnval = res && !gst_caps_is_empty (res);
 
 	gst_caps_unref (res);
 	gst_caps_unref (caps2);
